@@ -293,7 +293,7 @@ class attributes:
             spine.set_color(self.workspace_color if isinstance(self.spine_color, type(None)) else self.spine_color)
 
         if not isinstance(self.spines_removed, type(None)):
-            for i in self.spines_removed:
+            for i in range(len(self.spines_removed)):
                 if self.spines_removed[i] == 1:
                     self.ax.spines[["left", "bottom", "top", "right"][i]].set_visible(False)
 
