@@ -9,10 +9,15 @@ def fill():
 
     line(x=x, y=y)
     line(x=x, y=z)
-    fill_area(x=x, y=y, z=z, between=True, show=True, demo_pad_plot=True)
+    fill_area(x=x, y=y, z=z,
+              between=True, show=True, demo_pad_plot=True
+              )
 
 
 def scattr():
     scatter(grid=True, grid_lines='-.', cmap='magma', x_tick_number=5,
             plot_label="Graph", legend=True,
             color_bar=True, show=True)
+
+
+fill()
